package com.goldenwater.slgc.mapper;

import java.util.List;
import com.goldenwater.slgc.domain.SlgcWaterUnit;
import org.apache.ibatis.annotations.Mapper;

/** 水管单位 Mapper */
@Mapper
public interface SlgcWaterUnitMapper {
    /**
     * 查询水管单位列表
     *
     * @param slgcWaterUnit 查询条件
     * @return 水管单位列表
     */
    public List<SlgcWaterUnit> selectSlgcWaterUnitList(SlgcWaterUnit slgcWaterUnit);

    /**
     * 通过ID查询水管单位
     *
     * @param id 主键ID
     * @return 水管单位
     */
    public SlgcWaterUnit selectSlgcWaterUnitById(String id);

    /**
     * 新增水管单位
     *
     * @param slgcWaterUnit 水管单位
     * @return 影响行数
     */
    public int insertSlgcWaterUnit(SlgcWaterUnit slgcWaterUnit);

    /**
     * 修改水管单位
     *
     * @param slgcWaterUnit 水管单位
     * @return 影响行数
     */
    public int updateSlgcWaterUnit(SlgcWaterUnit slgcWaterUnit);

    /**
     * 批量删除水管单位
     *
     * @param ids 主键ID数组
     * @return 影响行数
     */
    public int deleteSlgcWaterUnitByIds(String[] ids);

    /**
     * 查询最大ID
     *
     * @return 最大ID
     */
    public Integer findMaxId();
}
